      subroutine getheight(itime,xt,yt,zt,pt,ht)
***********************************************************************
*                                                                     * 
*             TRAJECTORY MODEL SUBROUTINE GETHEIGHT                   *
*                                                                     *
***********************************************************************
*                                                                     * 
*             AUTHOR:      G. WOTAWA                                  *
*             DATE:        1994-04-07                                 *
*             Adaptation to Nesting: A. Stohl, 1999-01-07             * 
***********************************************************************
*                                                                     *
* DESCRIPTION: This subroutine calculates pressure [Pa] and geometric *
*              height [m] along trajectory for a given vertical       *
*              coordinate zt (eta ECMWF) on a given position (xt,yt). *
*                                                                     *
***********************************************************************
*                                                                     *
* INPUT:                                                              *
*                                                                     *
* itime     time relative to beginning of calculation period          *
* xt        x coordinate of point [grid units]                        *
* yt        y coordinate of point [grid units]                        *
* zt        z coordinate of point [units]                             *
*                                                                     *
***********************************************************************
*                                                                     *
* OUTPUT:                                                             *
*                                                                     *
* pt        pressure [Pa]                                             *
* ht        geometric height [m]                                      *
*                                                                     *
***********************************************************************
*
      include 'includepar'
      include 'includecom'

      integer i,itime,ihelp,indexf,j,ngrid

      real pp,xt,yt,zt,pt,ht,psint,xtn,ytn
*
* SEE WHICH FIELDS ARE NEEDED FOR INTERPOLATION
*

      do 10 i=1,numbwf

         if(wftime(i)*ldirect.ge.itime*ldirect) goto 15

10    continue

15    if(i.eq.1) then
         ihelp=1
      else
         ihelp=i-1
      endif
*
* needed times for interpolation: wftime(ihelp),wftime(ihelp+1)
*

            
*
* LOOK IF FIELD IS ACTUALLY IN MEMORY
* IF YES: INTERPOLATION IS DONE
* IF NO:  EXECUTION IS STOPPED --> ERROR
*
      do 30 i=1,3

         if (memtime(i).eq.wftime (ihelp)) goto 40

30    continue

      stop 'SUBROUTINE GETHEIGHT: FATAL ERROR '

40    indexf=i
      
      if(indexf.ge.3) then

      stop 'SUBROUTINE GETHEIGHT: FATAL ERROR '
                               
      endif

C Determine which nesting level to be used
******************************************

      ngrid=0
      do 12 j=numbnests,1,-1
        if ((xt.gt.xln(j)).and.(xt.lt.xrn(j)).and.
     +  (yt.gt.yln(j)).and.(yt.lt.yrn(j))) then
          ngrid=j
          goto 13
        endif
12      continue
13    continue

      if (ngrid.eq.0) then
        xtn=xt
        ytn=yt
        call levlininterpol(ps,nxmax,nymax,1,nx,ny,memind,
     +  xt,yt,1,memtime(indexf),memtime(indexf+1),itime,indexf,psint)
      else
        xtn=(xt-xln(ngrid))*xresoln(ngrid)
        ytn=(yt-yln(ngrid))*yresoln(ngrid)
        call levlininterpoln(psn,maxnests,nxmaxn,nymaxn,1,ngrid,
     +  nxn,nyn,memind,xtn,ytn,1,memtime(indexf),memtime(indexf+1),
     +  itime,indexf,psint)
      endif

      pt=pp(psint,zt)

      call zztrafo(ngrid,xtn,ytn,zt,memtime(indexf),memtime(indexf+1),
     +itime,indexf,psint,ht)

      return
      end
