      subroutine openflightoutput(error)
C                                   o
********************************************************************************
*                                                                              *
*   This routine opens the trajectory data output files.                       *
*                                                                              *
*     Authors: A. Stohl                                                        *
*                                                                              *
*     16 February 1994                                                         *
*                                                                              *
********************************************************************************
*                                                                              *
* Variables:                                                                   *
* compoint(maxpoint)   comment for each startpoint                             *
* datestring           date and time of model run                              *
* error                .true., if error ocurred in subprogram, else .false.    *
* numpoint             number of starting points                               *
*                                                                              *
* Constants:                                                                   *
* unittraj             unittraj+i are connected to trajectory output (point i) *
* unittraji            unittraji+i are connected to interpolated trajectories  *
*                                                                              *
********************************************************************************

      include 'includepar'
      include 'includecom'

      integer k
      logical error
      character datestring*24
     

      error=.false.


C Look for runtime
******************

C      call fdate(datestring)


C If possible, use the first 12 characters of the comment for the file 
C name identification.
*********************************************************************

C 1. if wanted, original trajectories (flexible time step)
**********************************************************

      if ((inter.eq.0).or.(inter.eq.2)) then
        k=index(compoint(1),' ')-1
        k=min(k,12)                        
          open(unittraj,file=path(2)(1:len(2))//'FLIGHT_'//compoint(1)
     +    (1:k),status='new',err=998)         
          write(unittraj,'(a69)') '*************************************
     +********************************'
          write(unittraj,'(a69)') '*                                           
     +                               *'
          write(unittraj,'(a69)') '*                     FLEXTRA MODEL O         
     +UTPUT                          *'
          write(unittraj,'(a69)') '*                     FOR ECMWF WINDF
     +IELDS                          *'
          write(unittraj,'(a69)') '*                                           
     +                               *'
          write(unittraj,'(a69)') '*************************************
     +********************************'
          write(unittraj,'(a69)') '*                                           
     +                               *'
          write(unittraj,'(a,a,a)') '*            TIME OF COMPUTATION: 
     + ' ,datestring(1:24),'            *'
          write(unittraj,'(a69)') '*                                           
     +                               *'
          write(unittraj,'(a69)') '*************************************
     +********************************'
          write(unittraj,'(a69)') '*                                           
     +                               *'
          if (kind(1).eq.1) then
          write(unittraj,'(a69)') '*           TYPE OF TRAJECTORIES:  3-
     +DIMENSIONAL                    *'
          else if (kind(1).eq.2) then
          write(unittraj,'(a69)') '*           TYPE OF TRAJECTORIES:  ON
     + MODEL LAYERS                  *'
          else if (kind(1).eq.4) then
          write(unittraj,'(a69)') '*           TYPE OF TRAJECTORIES:  IS
     +OBARIC                         *'
          else if (kind(1).eq.5) then
          write(unittraj,'(a69)') '*           TYPE OF TRAJECTORIES:  IS
     +ENTROPIC                       *'
          endif
          write(unittraj,'(a69)') '*                                           
     +                               *'
          write(unittraj,'(a69)') '*************************************
     +********************************'
          write(unittraj,'(a69)') '*                                           
     +                               *'
          write(unittraj,'(a69)') '*             INTEGRATION SCHEME:  PE          
     +TTERSSEN                       *'
          if (inpolkind.eq.1) then
          write(unittraj,'(a69)') '*           INTERPOLATION METHOD:  ID
     +EAL                            *'
          else
          write(unittraj,'(a69)') '*           INTERPOLATION METHOD:  LI
     +NEAR                           *'
          endif
          write(unittraj,'(a69)') '*                                           
     +                               *'
          write(unittraj,'(a,f5.2,a)') '*          SPATIAL CFL CRITERION
     +: ',cfl,'                             *'
          write(unittraj,'(a,f5.2,a)') '*         TEMPORAL CFL CRITERION
     +: ',cflt,'                             *'
          write(unittraj,'(a69)') '*                                           
     +                               *'
          write(unittraj,'(a69)') '*************************************
     +********************************'
          write(unittraj,'(a69)') '*                                           
     +                               *'
          write(unittraj,'(a)') '* START POINT COMMENT: '//
     +  compoint(1)(1:40)//'     *'
          write(unittraj,'(a)') '* MODEL RUN COMMENT: '//
     +  runcomment(1:47)//'*'
          write(unittraj,'(a69)') '*                                           
     +                               *'
          write(unittraj,'(a69)') '*************************************
     +********************************'
          write(unittraj,*)
      endif


C 2. if wanted, interpolated trajectories (constant time step)
**************************************************************

      if (inter.ge.1) then
        k=index(compoint(1),' ')-1
        k=min(k,12)                        
        open(unittraji,file=path(2)(1:len(2))//'FLIGHTI_'//compoint(1)
     +  (1:k),status='new',err=999)         
         write(unittraji,'(a69)') '*************************************
     +********************************'
         write(unittraji,'(a69)') '*                                           
     +                               *'
         write(unittraji,'(a69)') '*                     FLEXTRA MODEL O         
     +UTPUT                          *'
         write(unittraji,'(a69)') '*                     FOR ECMWF WINDF
     +IELDS                          *'
         write(unittraji,'(a69)') '*                                           
     +                               *'
         write(unittraji,'(a69)') '*************************************
     +********************************'
         write(unittraji,'(a69)') '*                                           
     +                               *'
         write(unittraji,'(a,a,a)') '*            TIME OF COMPUTATION: 
     + ',datestring(1:24),'          *'
         write(unittraji,'(a69)') '*                                           
     +                               *'
         write(unittraji,'(a69)') '*************************************
     +********************************'
         write(unittraji,'(a69)') '*                                           
     +                               *'
         if (kind(1).eq.1) then
         write(unittraji,'(a69)') '*           TYPE OF TRAJECTORIES:  3-
     +DIMENSIONAL                    *'
         else if (kind(1).eq.2) then
         write(unittraji,'(a69)') '*           TYPE OF TRAJECTORIES:  ON
     + MODEL LAYERS                  *'
         else if (kind(1).eq.4) then
         write(unittraji,'(a69)') '*           TYPE OF TRAJECTORIES:  IS
     +OBARIC                         *'
         else if (kind(1).eq.5) then
         write(unittraji,'(a69)') '*           TYPE OF TRAJECTORIES:  IS
     +ENTROPIC                       *'
         endif
         write(unittraji,'(a69)') '*                                           
     +                               *'
         write(unittraji,'(a69)') '*************************************
     +********************************'
         write(unittraji,'(a69)') '*                                           
     +                               *'
         write(unittraji,'(a69)') '*             INTEGRATION SCHEME:  PE          
     +TTERSSEN                       *'
         if (inpolkind.eq.1) then
         write(unittraji,'(a69)') '*           INTERPOLATION METHOD:  ID
     +EAL                            *'
         else
         write(unittraji,'(a69)') '*           INTERPOLATION METHOD:  LI
     +NEAR                           *'
         endif
         write(unittraji,'(a69)') '*                                           
     +                               *'
         write(unittraji,'(a,f5.2,a)') '*          SPATIAL CFL CRITERION
     +: ',cfl,'                             *'
         write(unittraji,'(a,f5.2,a)') '*         TEMPORAL CFL CRITERION
     +: ',cflt,'                             *'
         write(unittraji,'(a69)') '*                                           
     +                               *'
         write(unittraji,'(a69)') '*************************************
     +********************************'
         write(unittraji,'(a69)') '*                                           
     +                               *'
         write(unittraji,'(a)') '* START POINT COMMENT: '//
     + compoint(1)(1:40)//'     *'
         write(unittraji,'(a)') '* MODEL RUN COMMENT: '//
     +  runcomment(1:47)//'*'
         write(unittraji,'(a69)') '*                                           
     +                               *'
         write(unittraji,'(a69)') '*************************************
     +********************************'
         write(unittraji,*)
      endif

      return    

998   write(*,*)
      write(*,*) ' #### TRAJECTORY MODEL ERROR!   THE FILE       #### '
      write(*,*)
      write(*,*) '    '//path(2)(1:len(2))//'FLIGHT_'//compoint(1)(1:k)
      write(*,*)
      write(*,*) ' #### CANNOT BE OPENED. IF A FILE WITH THIS    #### '
      write(*,*) ' #### NAME ALREADY EXISTS, DELETE IT AND START #### '
      write(*,*) ' #### THE PROGRAM AGAIN.                       #### '
      error=.true.
      return

999   write(*,*)
      write(*,*) ' #### TRAJECTORY MODEL ERROR!   THE FILE       #### '
      write(*,*)
      write(*,*) path(2)(1:len(2))//'FLIGHTI_'//compoint(1)(1:k)
      write(*,*)
      write(*,*) ' #### CANNOT BE OPENED. IF A FILE WITH THIS    #### '
      write(*,*) ' #### NAME ALREADY EXISTS, DELETE IT AND START #### '
      write(*,*) ' #### THE PROGRAM AGAIN.                       #### '
      error=.true.

      return
      end
